package cz.upol.db;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.Statement;

public class ExampleClient {
	
    private String dbName = "demodb";
    private String host = "localhost:1527";
    
	private Connection con;
	
	/**
	 * Pripoji se k DB pres sitove rozhrani
	 */
	public void connectClient() throws SQLException, ClassNotFoundException, InstantiationException, IllegalAccessException {
		String connectionURL = "jdbc:derby://" + host + "/" + dbName + ";create=true";
		
		// vytvori pripojeni
		con = DriverManager.getConnection(connectionURL);
		System.out.println("Connecting to: " + connectionURL);
	}
	
	/**
	 * Zobrazi data z tabulky, ktera vznikla jako:
	 * CREATE TABLE demo (a int, b int, c varchar(50), PRIMARY KEY(a));
	 * INSERT INTO demo (a, b, c) VALUES (1, 10, 'Foo');
	 * INSERT INTO demo (a, b, c) VALUES (5, 15, 'Bar');
	 * INSERT INTO demo (a, b, c) VALUES (4, 45, 'Quux');
	 */
	public void listData() throws SQLException {
		try (Statement stmt = con.createStatement()) {
		
			// prevede dotaz
			stmt.executeQuery("SELECT * FROM demo");
			
			// ziska data
			try (ResultSet results = stmt.getResultSet()) {
			
				// je mozne ziskat i metadata 
				ResultSetMetaData metaData = results.getMetaData();
				
				// sloupce
				System.out.println("Pocet sloupcu: " + metaData.getColumnCount());
				for (int i = 0; i < metaData.getColumnCount(); i++)
					System.out.println(String.format("Sloupec #%1$s: %2$s\t(%3$s)", 
							(i + 1), 
							metaData.getColumnName(i + 1),
							metaData.getColumnTypeName(i + 1)));
				
				
				while (results.next()) {
					System.out.print(results.getInt(1)); // sloupce jsou indexovany od jedne
					System.out.print(", ");
					System.out.print(results.getInt(2));
					System.out.print(", ");
					System.out.println(results.getString("c")); // lze pristupovat i pres jmeno
				}
			}
		}
	}
	

	public void insertData(int a, int b, String c) throws SQLException {
		try (Statement stmt = con.createStatement()) {
			String query = "INSERT INTO demo (a, b, c) VALUES (" + a + ", " + b + ", '" + c + "')";
			System.out.println("Query: " + query);
			stmt.executeUpdate(query);
		}
	}

	public void disconnect() throws SQLException {
		con.close();
	}
	
	public static void main(String[] args) throws SQLException, ClassNotFoundException, InstantiationException, IllegalAccessException {
		ExampleClient example = new ExampleClient();
		example.connectClient();
		example.listData();
		example.insertData(22, 32, "Blah blah");
		example.listData();
		example.disconnect();
	}
}
