package cz.upol.db;

import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

public class ExampleEmbedded {
	
    private String dbName = "demodb";
    
	private Connection con;
	
	/**
	 * Pripoji se do vlozene databaze
	 */
	public void connectEmbedded() throws SQLException, ClassNotFoundException, InstantiationException, IllegalAccessException {
		String connectionURL = "jdbc:derby:" + dbName + ";create=true";
		
		// vytvori pripojeni
		con = DriverManager.getConnection(connectionURL);
		System.out.println("Connecting to: " + connectionURL);
	}
	
	/**
	 * Vraci true pokud databazi existuje tabulka demo 
	 */
	private boolean isReady() throws SQLException {
		DatabaseMetaData dbm = con.getMetaData();
		try (ResultSet tables = dbm.getTables(null, null, "DEMO", null)) {
			return tables.next();
		}
	}
	
	/**
	 * Vytvori a naplni tabulku (pouziva davkove zpracovani dat)
	 */
	private void initializeTable() throws SQLException {
		System.out.println("Vytvarim tabulku i s daty");
		try (Statement stmt = con.createStatement()) {
			stmt.addBatch("CREATE TABLE demo (a int, b int, c varchar(50), PRIMARY KEY(a))");
			stmt.addBatch("INSERT INTO demo (a, b, c) VALUES (1, 10, 'Foo')");
			stmt.addBatch("INSERT INTO demo (a, b, c) VALUES (5, 15, 'Bar')");
			stmt.addBatch("INSERT INTO demo (a, b, c) VALUES (4, 45, 'Quux')");
			stmt.executeBatch();
		}
	}
	
	/**
	 * Vypise obsah tabulky
	 */
	public void listData() throws SQLException {
		try (Statement stmt = con.createStatement()) {
		
			// prevede dotaz
			stmt.executeQuery("SELECT * FROM demo");
			
			// ziska data
			try (ResultSet results = stmt.getResultSet()) {
				System.out.println("Tabulka: demo");
				while (results.next()) {
					System.out.print(results.getInt(1)); // sloupce jsou indexovany od jedne
					System.out.print(", ");
					System.out.print(results.getInt(2));
					System.out.print(", ");
					System.out.println(results.getString("c")); // lze pristupovat i pres jmeno
				}
			}
		}
	}

	public void disconnect() throws SQLException {
		con.close();
	}
	
	public static void main(String[] args) throws SQLException, ClassNotFoundException, InstantiationException, IllegalAccessException {
		ExampleEmbedded example = new ExampleEmbedded();
		example.connectEmbedded();
		if (!example.isReady())
			example.initializeTable();
		
		example.listData();
		example.disconnect();
	}
}
